vim.api.nvim_create_autocmd('BufWritePre', {
  pattern = '*.go',
  callback = function()
    vim.lsp.buf.code_action({ context = { only = { 'source.organizeImports' } }, apply = true })
    vim.lsp.buf.format()
  end
})

local capabilities = require('cmp_nvim_lsp').default_capabilities()

require('lspconfig').gopls.setup {
    capabilities = capabilities,
    flags = {
        debounce_text_changes = 150,
    },
    cmd = {'gopls', '--remote=auto'},
    settings = {
        gopls = {
            vulncheck = "Imports",
            gofumpt = true,
            usePlaceholders = true,
            completeUnimported = true,
            experimentalPostfixCompletions = true,
            analyses = {
                assign = true,
                atomic = true,
                atomicalign = true,
                bools = true,
                buildtag = true,
                composites = true,
                copylocks = true,
                erroras = true,
                fieldalignment = true,
                httpresponse = true,
                ifaceassert = true,
                infertypeargs = true,
                loopclosure = true,
                lostcancel = true,
                nilfunc = true,
                nilness = true,
                printf = true,
                shadow = true,
                simplifyrange = true,
                simplifyslice = true,
                sortslice = true,
                stdmethods = true,
                stringintconv = true,
                testinggoroutine = true,
                tests = true,
                unmarshal = true,
                unreachable = true,
                unsafeptr = true,
                unusedparams = true,
                unusedresult = true,
                unusedwrite = true,
                useany = true,
                nonewvars = true,
            },
        },
    },
}

-- Change local setting to separate 3rd-party and local imports with go.mod prefix
